==> s-webpack-cdn-plugin-1.0.1.tgz: package/lib/hook.js <==
"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __generator = (this && this.__generator) || function (thisArg, body) {
    var _ = { label: 0, sent: function() { if (t[0] & 1) throw t[1]; return t[1]; }, trys: [], ops: [] }, f, y, t, g;
    return g = { next: verb(0), "throw": verb(1), "return": verb(2) }, typeof Symbol === "function" && (g[Symbol.iterator] = function() { return this; }), g;
    function verb(n) { return function (v) { return step([n, v]); }; }
    function step(op) {
        if (f) throw new TypeError("Generator is already executing.");
        while (g && (g = 0, op[0] && (_ = 0)), _) try {
            if (f = 1, y && (t = op[0] & 2 ? y["return"] : op[0] ? y["throw"] || ((t = y["return"]) && t.call(y), 0) : y.next) && !(t = t.call(y, op[1])).done) return t;
            if (y = 0, t) op = [op[0] & 2, t.value];
            switch (op[0]) {
                case 0: case 1: t = op; break;
                case 4: _.label++; return { value: op[1], done: false };
                case 5: _.label++; y = op[1]; op = [0]; continue;
                case 7: op = _.ops.pop(); _.trys.pop(); continue;
                default:
                    if (!(t = _.trys, t = t.length > 0 && t[t.length - 1]) && (op[0] === 6 || op[0] === 2)) { _ = 0; continue; }
                    if (op[0] === 3 && (!t || (op[1] > t[0] && op[1] < t[3]))) { _.label = op[1]; break; }
                    if (op[0] === 6 && _.label < t[1]) { _.label = t[1]; t = op; break; }
                    if (t && _.label < t[2]) { _.label = t[2]; _.ops.push(op); break; }
                    if (t[2]) _.ops.pop();
                    _.trys.pop(); continue;
            }
            op = body.call(thisArg, _);
        } catch (e) { op = [6, e]; y = 0; } finally { f = t = 0; }
        if (op[0] & 5) throw op[1]; return { value: op[0] ? op[1] : void 0, done: true };
    }
};
/**
 * 配置参数
 * @param config 需要配置的参数以及环境
 */
// const { Configuration, EnvProps, FormProps } = require("./configuration.ts");
var _a = require("./configuration"), Configuration = _a.Configuration, EnvProps = _a.EnvProps, StorageInterface = _a.StorageInterface, FormProps = _a.FormProps;
var upload = require('./upload');
var replace = require('./replace');
var chalk = require("chalk");
var Webpack5CDNPlugin = /** @class */ (function () {
    function Webpack5CDNPlugin(config) {
        this.totalUploadFileNum = 0;
        this.hasUploadFileNum = 0;
        this.config = upload.standardize(config);
    }
    Webpack5CDNPlugin.prototype.apply = function (compiler) {
        var _this = this;
        compiler.hooks.emit.tapAsync('Webpack5CDNPlugin', function (compilation, callback) { return __awaiter(_this, void 0, void 0, function () {
            var assets, chunks, uploadAssets, replaceAssetsHtml;
            var _this = this;
            return __generator(this, function (_a) {
                switch (_a.label) {
                    case 0:
                        assets = compilation.assets, chunks = compilation.chunks;
                        uploadAssets = Object.keys(assets).filter(function (key) { return !key.endsWith(".html"); });
                        replaceAssetsHtml = Object.keys(assets).filter(function (key) { return key.endsWith(".html"); });
                        this.totalUploadFileNum = uploadAssets.length;
                        return [4 /*yield*/, Promise.all(uploadAssets.map(function (fileKey) { return __awaiter(_this, void 0, void 0, function () {
                                var content, newContent, url, error_1;
                                return __generator(this, function (_a) {
                                    switch (_a.label) {
                                        case 0:
                                            _a.trys.push([0, 2, , 3]);
                                            content = assets[fileKey].source();
                                            newContent = fileKey.endsWith(".css") ? replace.interpolateCssAssets(content) : content;
                                            return [4 /*yield*/, upload.uploadContent(newContent, fileKey, this.config)];
                                        case 1:
                                            url = _a.sent();
                                            this.hasUploadFileNum++;
                                            console.log(chalk.yellow("上传完毕 " + url));
                                            console.log('当前进度: ' + this.hasUploadFileNum + '/' + this.totalUploadFileNum);
                                            return [3 /*break*/, 3];
                                        case 2:
                                            error_1 = _a.sent();
                                            console.error("\u8BF7\u6C42 ".concat(fileKey, " \u5931\u8D25: ").concat(error_1));
                                            throw error_1;
                                        case 3: return [2 /*return*/];
                                    }
                                });
                            }); }))];
                    case 1:
                        _a.sent();
                        return [4 /*yield*/, Promise.all(replaceAssetsHtml.map(function (fileKey) {
                                try {
                                    var htmlContent_1 = assets[fileKey].source();
                                    assets["".concat(fileKey, ".bak")] = {
                                        source: function () { return htmlContent_1; },
                                        size: function () { return htmlContent_1.length; },
                                    };
                                    var newHtmlContent_1 = replace.interpolateHTMLAssets(fileKey, htmlContent_1, _this.config);
                                    assets[fileKey] = {
                                        source: function () { return newHtmlContent_1; },
                                        size: function () { return newHtmlContent_1.length; },
                                    };
                                }
                                catch (error) {
                                    console.error("\u4FEE\u6539 ".concat(fileKey, " cdn\u5730\u5740\u5931\u8D25: ").concat(error));
                                    throw error;
                                }
                            }))];
                    case 2:
                        _a.sent();
                        callback();
                        return [2 /*return*/];
                }
            });
        }); });
    };
    return Webpack5CDNPlugin;
}());
exports.default = Webpack5CDNPlugin;

==> s-webpack-cdn-plugin-1.0.2.tgz: package/lib/hook.js <==
"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __generator = (this && this.__generator) || function (thisArg, body) {
    var _ = { label: 0, sent: function() { if (t[0] & 1) throw t[1]; return t[1]; }, trys: [], ops: [] }, f, y, t, g;
    return g = { next: verb(0), "throw": verb(1), "return": verb(2) }, typeof Symbol === "function" && (g[Symbol.iterator] = function() { return this; }), g;
    function verb(n) { return function (v) { return step([n, v]); }; }
    function step(op) {
        if (f) throw new TypeError("Generator is already executing.");
        while (g && (g = 0, op[0] && (_ = 0)), _) try {
            if (f = 1, y && (t = op[0] & 2 ? y["return"] : op[0] ? y["throw"] || ((t = y["return"]) && t.call(y), 0) : y.next) && !(t = t.call(y, op[1])).done) return t;
            if (y = 0, t) op = [op[0] & 2, t.value];
            switch (op[0]) {
                case 0: case 1: t = op; break;
                case 4: _.label++; return { value: op[1], done: false };
                case 5: _.label++; y = op[1]; op = [0]; continue;
                case 7: op = _.ops.pop(); _.trys.pop(); continue;
                default:
                    if (!(t = _.trys, t = t.length > 0 && t[t.length - 1]) && (op[0] === 6 || op[0] === 2)) { _ = 0; continue; }
                    if (op[0] === 3 && (!t || (op[1] > t[0] && op[1] < t[3]))) { _.label = op[1]; break; }
                    if (op[0] === 6 && _.label < t[1]) { _.label = t[1]; t = op; break; }
                    if (t && _.label < t[2]) { _.label = t[2]; _.ops.push(op); break; }
                    if (t[2]) _.ops.pop();
                    _.trys.pop(); continue;
            }
            op = body.call(thisArg, _);
        } catch (e) { op = [6, e]; y = 0; } finally { f = t = 0; }
        if (op[0] & 5) throw op[1]; return { value: op[0] ? op[1] : void 0, done: true };
    }
};
/**
 * 配置参数
 * @param config 需要配置的参数以及环境
 */
// const { Configuration, EnvProps, FormProps } = require("./configuration.ts");
var _a = require("./configuration"), Configuration = _a.Configuration, EnvProps = _a.EnvProps, StorageInterface = _a.StorageInterface, FormProps = _a.FormProps, FilesMapProps = _a.FilesMapProps;
var upload = require('./upload');
var replace = require('./replace');
var chalk = require("chalk");
var Webpack5CDNPlugin = /** @class */ (function () {
    function Webpack5CDNPlugin(config) {
        this.totalUploadFileNum = 0;
        this.hasUploadFileNum = 0;
        this.filesMap = {};
        this.domain = "";
        this.config = upload.standardize(config);
    }
    Webpack5CDNPlugin.prototype.apply = function (compiler) {
        var _this = this;
        compiler.hooks.emit.tapAsync('Webpack5CDNPlugin', function (compilation, callback) { return __awaiter(_this, void 0, void 0, function () {
            var assets, uploadAssets, replaceAssetsHtml, replaceAssetsCss;
            var _this = this;
            return __generator(this, function (_a) {
                switch (_a.label) {
                    case 0:
                        assets = compilation.assets;
                        uploadAssets = Object.keys(assets).filter(function (key) { return !key.endsWith(".html") && !key.endsWith(".css"); });
                        replaceAssetsHtml = Object.keys(assets).filter(function (key) { return key.endsWith(".html"); });
                        replaceAssetsCss = Object.keys(assets).filter(function (key) { return key.endsWith(".css"); });
                        this.totalUploadFileNum = uploadAssets.length + replaceAssetsCss.length;
                        return [4 /*yield*/, Promise.all(uploadAssets.map(function (fileKey) { return __awaiter(_this, void 0, void 0, function () {
                                var content, url, error_1;
                                return __generator(this, function (_a) {
                                    switch (_a.label) {
                                        case 0:
                                            _a.trys.push([0, 2, , 3]);
                                            content = assets[fileKey].source();
                                            return [4 /*yield*/, upload.uploadContent(content, fileKey, this.config)];
                                        case 1:
                                            url = _a.sent();
                                            this.filesMap[fileKey] = url;
                                            this.hasUploadFileNum++;
                                            console.log(chalk.yellow("上传完毕 " + url));
                                            console.log('当前进度: ' + this.hasUploadFileNum + '/' + this.totalUploadFileNum);
                                            return [3 /*break*/, 3];
                                        case 2:
                                            error_1 = _a.sent();
                                            console.error("\u8BF7\u6C42 ".concat(fileKey, " \u5931\u8D25: ").concat(error_1));
                                            throw error_1;
                                        case 3: return [2 /*return*/];
                                    }
                                });
                            }); }))];
                    case 1:
                        _a.sent();
                        this.domain = replace.interpolateDomains(this.filesMap, this.config);
                        return [4 /*yield*/, Promise.all(replaceAssetsCss.map(function (fileKey) { return __awaiter(_this, void 0, void 0, function () {
                                var content, newContent, url, error_2;
                                return __generator(this, function (_a) {
                                    switch (_a.label) {
                                        case 0:
                                            _a.trys.push([0, 2, , 3]);
                                            content = assets[fileKey].source();
                                            newContent = replace.interpolateCssAssets(content, this.domain);
                                            return [4 /*yield*/, upload.uploadContent(newContent, fileKey, this.config)];
                                        case 1:
                                            url = _a.sent();
                                            this.hasUploadFileNum++;
                                            console.log(chalk.yellow("上传完毕 " + url));
                                            console.log('当前进度: ' + this.hasUploadFileNum + '/' + this.totalUploadFileNum);
                                            return [3 /*break*/, 3];
                                        case 2:
                                            error_2 = _a.sent();
                                            console.error("\u8BF7\u6C42 ".concat(fileKey, " \u5931\u8D25: ").concat(error_2));
                                            throw error_2;
                                        case 3: return [2 /*return*/];
                                    }
                                });
                            }); }))];
                    case 2:
                        _a.sent();
                        return [4 /*yield*/, Promise.all(replaceAssetsHtml.map(function (fileKey) {
                                try {
                                    var htmlContent_1 = assets[fileKey].source();
                                    assets["".concat(fileKey, ".bak")] = {
                                        source: function () { return htmlContent_1; },
                                        size: function () { return htmlContent_1.length; },
                                    };
                                    var newHtmlContent_1 = replace.interpolateHTMLAssets(htmlContent_1, _this.domain);
                                    assets[fileKey] = {
                                        source: function () { return newHtmlContent_1; },
                                        size: function () { return newHtmlContent_1.length; },
                                    };
                                }
                                catch (error) {
                                    console.error("\u4FEE\u6539 ".concat(fileKey, " cdn\u5730\u5740\u5931\u8D25: ").concat(error));
                                    throw error;
                                }
                            }))];
                    case 3:
                        _a.sent();
                        callback();
                        return [2 /*return*/];
                }
            });
        }); });
    };
    return Webpack5CDNPlugin;
}());
exports.default = Webpack5CDNPlugin;
